nyx_printer_method_channel library
The method channel implementation of the Nyx printer plugin.
Classes
- MethodChannelNyxPrinter
- A platform-specific implementation of NyxPrinterPlatform using method channels. This class communicates with the native platform to perform printing tasks.